---
title: <span class="badge object-type-enum"></span> BarGaugeNamePlacement
---
# <span class="badge object-type-enum"></span> BarGaugeNamePlacement

Allows for the bar gauge name to be placed explicitly

## Definition

```python
class BarGaugeNamePlacement(enum.StrEnum):
    """
    Allows for the bar gauge name to be placed explicitly
    """

    AUTO = "auto"
    TOP = "top"
    LEFT = "left"
```
